capture log close
clear all
macro drop _all
version 16.1
cd "/Volumes/Mike2019/MC_CLIENTS/2021/ACCC Electricity Benchmarking/Stata"
set more off
log using crDNSPbench-firm3, replace text
set scheme vg_s1c

/*--------------------------------------------------------------------------
Project: Economic Insights DNSP Benchmarking
Author:  Michael Cunningham
File:    crDNSPbench-firm3.do
Initial Date:    25-June-2021 (as cr_DNSPbench-firm)
Revised Date:	 25-Sep-2021
--------------------------------------------------------------------------*/

local varlist revenue energy customers maxdemand ratchetmd circlength cmos ///
	price_cmos opex price_opex overheadst overheadd undergrst undergrd ///
    transform auc_overheadst auc_overheadd auc_undergrst auc_undergrd  ///
	auc_transform  	
	
tempfile inddat	


import excel using DNSPbench_v3.xlsx, sheet("Shazam DNSP Data") firstrow ///
	cellrange(A1:X196) case(l) clear
replace cmos = 1 if cmos < 1

label variable dnsp 		"Distribution Network Service Provider"
label variable year 		"Year (Financial or calendar as applicable)"
label variable revenue   	"Total Revenue ($'000)"
label variable energy    	"Energy (GWh)"	
label variable customers 	"Customer Numbers (No.)"	
label variable maxdemand 	"Maximum Demand (MW)"
label variable ratchetmd   	"Ratched Maximum Demand	(MW)"
label variable circlength   "Circuit Length	(kms)"
label variable cmos   		"Customer Minutes Off Supply (mins)"	
label variable price_cmos   "Price: Customer Minutes Off Supply ($/min)"	
label variable opex   		"Opex ($'000)"
label variable price_opex   "Price: Opex (Index 2006 = 1)"
label variable overheadst	"Overhead Subtransmission Lines (33kV and over) (MVAkms)"
label variable overheadd    "Overhead Distribution Lines (under 33kV) (MVAkms)"
label variable undergrst    "Underground Subtransmission Lines (33kV and over) (MVAkms)"
label variable undergrd     "Underground Distribution Lines (under 33kV) (MVAkms)"	
label variable transform    "Transformers Excluding First Stage of Two Stage (MVA)"	
label variable auc_overheadst "AUC Overhead Subtransmission ($'000)"	
label variable auc_overheadd "AUC Overhead Distribution ($'000)"	
label variable auc_undergrst "AUC Underground Subtransmission ($'000)"	
label variable auc_undergrd  "AUC Underground Distribution ($'000)"	
label variable auc_transform "AUC Transformers Excluding First Stage of Two Stage ($'000)"	
label variable ucshare     "Share of Underground Cables (Fraction)"		


label define dnsplab 1 "1.ACT: Evoenergy" 2 "2.AGD: Ausgrid" ///
	3 "3.CIT: CitiPower" 4 "4.END: Endeavour Energy" 5 "5.ENX: Energex" ///
	6 "6.ERG: Ergon Energy" 7 "7.ESS: Essential Energy" 8 "8.JEN: Jemena" ///
	9 "9.PCR: Powercor" 10 "10.SAP: SA Power Networks" ///
	11 "11.AND: AusNet Dist." 12 "12.TND: TasNetworks Dist." ///
	13 "13.UED: United Energy"																
label values dnsp dnsplab

gen byte state = 0
replace state = 1 if dnsp == 1
replace state = 2 if dnsp == 2 | dnsp == 4 | dnsp == 7
replace state = 3 if dnsp == 3 | dnsp == 8 | dnsp == 9 | dnsp == 11 | dnsp == 13
replace state = 4 if dnsp == 5 | dnsp == 6
replace state = 5 if dnsp == 10
replace state = 6 if dnsp == 12
label define statelab 1 "ACT" 2 "NSW" 3 "VIC" 4 "QLD" 5 "SA" 6 "TAS"
label values state statelab

sort dnsp year
xtset dnsp year

gen mdindex = 1
replace mdindex = (maxdemand / maxdemand[_n-1]) * mdindex[_n-1] if year > 2006

format %14.0g `varlist'

save dnspbench-firm3, replace


describe, fullnames
tab1 dnsp year
summarize `varlist' ucshare
misstable summarize `varlist' ucshare

*** Create individual DNSP Shazam input data files ********
		
local datfiles EVOdata.csv AGDdata.csv CITdata.csv ENDdata.csv ///
	ENXdata.csv ERGdata.csv ESSdata.csv JENdata.csv PCRdata.csv ///
	SAPdata.csv ANDdata.csv  TNDdata.csv UEDdata.csv

local j = 1	
foreach k of local datfiles {
	outsheet year `varlist' mdindex using `k' if dnsp == `j', comma replace
	local ++j
}

*** Create pooled DNSP Shazam input data file ********

outsheet dnspyear `varlist' ucshare using DNSPdata.csv, comma replace

* Create industry aggregates for use in Shazam

gen double cost_cmos = price_cmos * cmos
gen double ropex = opex / price_opex

sort year dnsp

collapse (sum) `varlist' cost_cmos ropex, by(year) 

replace price_cmos = cost_cmos / cmos
replace price_opex = opex / ropex

gen double mdindex = 1
replace mdindex = maxdemand / maxdemand[_n-1] * mdindex[_n-1] if year > 2006

outsheet year revenue energy ratchetmd customers circlength cmos price_cmos ///
	opex price_opex overheadst overheadd undergrst undergrd transform ///
	auc_overheadst auc_overheadd auc_undergrst auc_undergrd	auc_transform ///
	maxdemand mdindex using DINDdata.csv , comma replace

describe

drop cost_cmos ropex
gen dnsp = 14
save `inddat'

use dnspbench-firm3, clear
drop ucshare state dnspyear

append using `inddat'
label define dnsplab 14 "14.Total Industry", add 

describe

save dnspbench-firm3x, replace



log close
exit

